@@ -6,15 +6,25 @@ CLI interface for ✉️💣 **LetterBomb**.
 
 ----
 
--h, --help            show this help message and exit
--v, --version         show program's version number and exit
--b, --bundle          pack the HackMii installer into archive
--l LOGFILE, --logfile LOGFILE
-                      filepath to put log output
--g {debug,info,warn,error,critical}, --loglevel {debug,info,warn,error,critical}
-                      minimum logging level
+positional arguments:
+  * mac                   string of Wii's MAC address
+  * {U,E,K,J}             uppercase letter of Wii's region
+
+optional arguments:
+  -h, --help            show this help message and exit
+  -v, --version         show program's version number and exit
+  -o OUTFILE, --outfile OUTFILE
+                        filename of ZIP archive. If omitted,
+                        bytes of ZIP archive will be written to stdout
+  -b, --bundle          pack the HackMii installer into archive
+  -l LOGFILE, --logfile LOGFILE
+                        filepath to put log output
+  -g {debug,info,warn,error,critical}, --loglevel {debug,info,warn,error,critical}
+                        minimum logging level
 """
 import argparse
+import sys
+
 import letterbomb
 
 if __name__ == "__main__":
@@ -27,21 +37,22 @@ if __name__ == "__main__":
     )
     parser.add_argument("mac", help="string of Wii's MAC address")
     parser.add_argument(
-        "region", choices=letterbomb.REGION_LIST, help="single-letter of Wii's region"
+        "region",
+        choices=letterbomb.REGION_LIST,
+        help="uppercase letter of Wii's region",
+    )
+    parser.add_argument(
+        "-o",
+        "--outfile",
+        help="filename of ZIP archive. If omitted, bytes of ZIP archive will be written to stdout",
+        default="",
     )
-    parser.add_argument("outfile", help="filename of ZIP archive")
     parser.add_argument(
         "-b",
         "--bundle",
         action="store_true",
         help="pack the HackMii installer into archive",
     )
-    parser.add_argument(
-        "-i",
-        "--io-bytes",
-        action="store_true",
-        help="return bytes I/O instead",
-    )
     parser.add_argument("-l", "--logfile", help="filepath to put log output")
     parser.add_argument(
         "-g",
@@ -57,8 +68,14 @@ if __name__ == "__main__":
         print(vargs)
     if vargs["logfile"]:
         LOGGING_FILE = letterbomb.pathlib.Path(vargs["logfile"]).expanduser()
-    if vargs["io-bytes"]:
-        letterbomb.write_stream(vargs["mac"], vargs["region"], vargs["bundle"])
-    letterbomb.write_zip(
+    result = letterbomb.write(
         vargs["mac"], vargs["region"], vargs["bundle"], vargs["outfile"]
     )
+
+    if not vargs["outfile"]:
+        # No outfile, return raw
+        sys.stdout.buffer.write(result.getvalue())
+        sys.stdout.buffer.flush()
+    else:
+        # Outfile, show resulting file name as string so it can be passed
+        print(str(result))
